@@ -14,7 +14,7 @@ use Monitoring::Generator::TestConfig::P1Data;
 use Monitoring::Generator::TestConfig::Modules::Shinken;
 use Monitoring::Generator::TestConfig::ShinkenInitScriptData;
 
-our $VERSION = '0.40';
+our $VERSION = '0.42';
 
 =head1 NAME
 
@@ -285,7 +285,7 @@ sub create {
     $objects = $self->_set_timeperiods_cfg($objects);
     my $obj_prefix = '/etc/conf.d';
     my $plg_prefix = '/plugins';
-    if($self->{'layout'} eq 'omd') { 
+    if($self->{'layout'} eq 'omd') {
         $obj_prefix = '/etc/nagios/conf.d/generated';
         $plg_prefix = '/local/lib/nagios/plugins';
     }
@@ -299,7 +299,7 @@ sub create {
         { file => $obj_prefix.'/commands.cfg',         data => $self->_create_object_conf('command',       $objects->{'command'})           },
         { file => $plg_prefix.'/test_servicecheck.pl', data => Monitoring::Generator::TestConfig::ServiceCheckData->get_test_servicecheck() },
         { file => $plg_prefix.'/test_hostcheck.pl',    data => Monitoring::Generator::TestConfig::HostCheckData->get_test_hostcheck()       },
-        { file => '/recreate.pl',                      data => $self->_get_recreate_pl()                                                    },
+        { file => '/recreate.pl',                      data => $self->_get_recreate_pl($self->_get_used_libs($self->{'output_dir'}.'/recreate.pl')) },
     ];
 
     if($self->{'layout'} ne 'omd') {
@@ -379,7 +379,7 @@ sub _set_hosts_cfg {
     $objects->{'host'} = [] unless defined $objects->{'host'};
 
     my $hostconfig = {
-        'name'                           => 'generic-host',
+        'name'                           => 'generic-mgt-test-host',
         'notifications_enabled'          => 1,
         'event_handler_enabled'          => 1,
         'flap_detection_enabled'         => 1,
@@ -416,7 +416,7 @@ sub _set_hosts_cfg {
             my $host = {
                 'host_name'     => $self->{'prefix'}."router_".$nr,
                 'alias'         => $self->{'prefix'}.$type."_".$nr,
-                'use'           => 'generic-host',
+                'use'           => 'generic-mgt-test-host',
                 'address'       => '127.0.'.$x.'.1',
                 'hostgroups'    => $hostgroup,
                 'check_command' => 'test-check-host-alive!'.$type,
@@ -462,7 +462,7 @@ sub _set_hosts_cfg {
         my $host = {
             'host_name'     => $self->{'prefix'}."host_".$nr,
             'alias'         => $self->{'prefix'}.$type."_".$nr,
-            'use'           => 'generic-host',
+            'use'           => 'generic-mgt-test-host',
             'address'       => '127.0.'.$cur_router.'.'.($x + 1),
             'hostgroups'    => $hostgroup.','.$type,
             'check_command' => 'test-check-host-alive!'.$type,
@@ -511,7 +511,7 @@ sub _set_services_cfg {
     $objects->{'service'} = [] unless defined $objects->{'service'};
 
     my $serviceconfig = {
-        'name'                            => 'generic-service',
+        'name'                            => 'generic-mgt-test-service',
         'active_checks_enabled'           => 1,
         'passive_checks_enabled'          => 1,
         'parallelize_check'               => 1,
@@ -558,7 +558,7 @@ sub _set_services_cfg {
                 'host_name'             => $self->{'prefix'}."host_".$host_nr,
                 'service_description'   => $self->{'prefix'}.$type."_".$service_nr,
                 'check_command'         => 'check_service!'.$type,
-                'use'                   => 'generic-service',
+                'use'                   => 'generic-mgt-test-service',
                 'servicegroups'         => $servicegroup.','.$type,
             };
 
@@ -942,6 +942,7 @@ sub _get_types {
 ########################################
 sub _get_recreate_pl {
     my $self  = shift;
+    my $libs  = shift || '';
     my $pl;
 
     $Data::Dumper::Sortkeys = 1;
@@ -951,6 +952,7 @@ sub _get_recreate_pl {
 
     $pl  = <<EOT;
 #!$^X
+$libs
 use Monitoring::Generator::TestConfig;
 my \$ngt = Monitoring::Generator::TestConfig->new(
 $conf
@@ -981,6 +983,20 @@ sub _sort_object_key {
     return $a cmp $b;
 }
 
+########################################
+sub _get_used_libs {
+    my($self, $file) = @_;
+    my $libs = '';
+    return $libs unless -r $file;
+    open(my $fh, '<', $file) or die('cannot read file '.$file.': '.$!);
+    while(my $line = <$fh>) {
+        next unless $line =~ m/^\s*use\s+lib\s+/gmx;
+        $libs .= $line;
+    }
+    close($fh);
+    return $libs;
+}
+
 1;
 
 __END__
